- https://github.com/flatgeobuf/flatgeobuf/blob/2876fac0456775199a061313d7d6fcc0b6f338c7/test/data/countries.fgb
- https://raw.githubusercontent.com/flatgeobuf/flatgeobuf/master/test/data/countries.fgb


### `nz-building-outlines-small.fgb`

```
ogr2ogr nz-building-outlines-small.fgb /vsicurl/https://storage.googleapis.com/open-geodata/linz-examples/nz-building-outlines.parquet -limit 2000
```
